<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="ms">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proksi Aplikasi</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Tanda &quot;Guna satu proksi&quot; pada menu konteks aplikasi di dalam Pelancar selepas dikonfigurkan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Alamat IP tidak sah</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port tidak sah</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Putuskan</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Putuskan</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Anda pasti mahu memadam konfigurasi ini?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Sambungan Berwayar %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Kawasan Khas</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Sambungan Tanpa Wayar %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Sambungan PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN baharu</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Jenis VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksport</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>L2TP VPN %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>PPTP VPN %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>OpenVPN VPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>StrongSwan VPN %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>OpenConnect VPN %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proksi Aplikasi</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kawasan Khas Peribadi</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Perincian Rangkaian</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proksi Sistem</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Penyesuai Rangkaian Berwayar</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tambah Sambungan Rangkaian</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Penyesuai Rangkaian Tanpa Wayar</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Sambung ke rangkaian tersembunyi</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Cipta Sambungan PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Cipta VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasi URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Kawasan Khas</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Cipta Kawasan Khas</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Antara Muka</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Jalur</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Utama</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Topeng Rangkaian</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kelajuan</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Alamat DNS tidak sah</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Tidak Diikat</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Alamat MAC Peranti</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Alamat MAC Klon</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Suaikan MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Am</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Am</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Nama sudah wujud</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Auto Sambung</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Kawasan Khas</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Tambah Tetapan</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Cipta Kawasan Khas</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Alamat IP tidak sah</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Topeng rangkaian tidak sah</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Topeng Rangkaian</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Alamat IP tidak sah</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abai</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Alamat IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Hanya dilaksana dalam sumber berkenaan</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Kaedah</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Topeng Rangkaian</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Alamat IP tidak sah</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Topeng rangkaian tidak sah</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Kaedah</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abai</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Perincian Rangkaian</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proksi Sistem</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proksi Aplikasi</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Perincian Rangkaian</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dilumpuhkan</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Dikonfigut oleh Pengurus Rangkaian</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kawasan Khas Peribadi</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Perkhidmatan</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Nafi Pengesahihan EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Nafi Pengesahihan PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Nafi Pengesahihan CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Nafi Pengesahihan MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Nafi Pengesahihan MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Tiada Pemampatan Data BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Tiada Pemampatan Data Kempis</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Tiada Pemampatan Pengepala TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Tiada Pemampatan Medan Protokol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Tiada Pemampatan Alamat/Kawalan</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Hantar Paket Gema PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Guna MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Berkeadaan</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Cipta Sambungan PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proksi Sistem</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proksi HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proksi HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proksi FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proksi SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Abai konfigurasi proksi untuk hos dan domain di atas</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasi URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Keselamatan</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS Berterowong</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP Terlindung</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Simpan kata laluan bagi pengguna ini</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Simpan kata laluan bagi semua pengguna</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Sentiasa tanya saya</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dilumpuhkan</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Awanama</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Disahihkan</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Kedua-duanya</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versi 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versi 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Pengesahihan EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identiti</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pilihan Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Persendirian</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Sijil CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Sijil Pengguna</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Awanama</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Pembekalan</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Fail PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Pengesahihan Dalaman</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versi PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Kata Laluan Persendirian</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Kata laluan tidak sah</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Persendirian</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Keselamatan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Keselamatan Diperlukan</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Kata laluan tidak sah</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Persendirian</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Kunci terkongsi</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistem terbuka</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Keselamatan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Pengesahihan</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Lanjutan</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Suaikan Port Get Laluan</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port Get Laluan</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Suaikan Perundingan Semula Dalaman</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Perundingan Semula Dalaman</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Guna Pemampatan Data LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Guna Sambungan TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Guna Peranti TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Suaikan MTU Terowong</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Suaikan Saiz Cebisan UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Saiz Cebisan UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Hadkan MSS TCP Terowong</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Rawakkan Hos Jauh</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Lanjutan</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (lalai)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Selamat (lalai)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Lemah</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Bila Tersedia (lalai)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Sentiasa</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dilumpuhkan</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Kumpulan DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Kumpulan DH 2 (lalai)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Kumpulan DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Pelayan (lalai)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Kumpulan DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Penyulitan</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mod Penyusuran NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Kumpulan DH IKE</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Kerahsiaan Maju</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port Setempat</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Lumpuhkan Pengesanan Rakan Mati</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>IPsec VPN</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Benarkan IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nama Kumpulan</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Kumpulan</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Kunci Pra-Kongsi</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritma Fasa1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritma Fasa2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Sijil CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proksi</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Benarkan Trojan Desktop Selamat Cisco</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Skrip CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Sijil Pengguna</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Persendirian</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Guna FSID untuk Frasa Laluan Kunci</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sijil (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Sijil dengan Kata Laluan (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Kunci Statik</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Disimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Jenis Pengesahihan</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Sijil CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Sijil Pengguna</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Persendirian</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pilihan Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Kata Laluan Persendirian</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Suaikan Arah Kunci</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Arah Kunci</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Jauh</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Setempat</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>PPP VPN</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Semua Tersedia (lalai)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (kurang  selamat)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (paling selamat)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Nafi Pengesahihan EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Nafi Pengesahihan PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Nafi Pengesahihan CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Nafi Pengesahihan MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Nafi Pengesahihan MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Tiada Pemampatan Data BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Tiada Pemampatan Data Kempis</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Tiada Pemampatan Pengepala TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Tiada Pemampatan Medan Protokol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Tiada Pemampatan Alamat/Kawalan</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Hantar Paket Gema PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Guna MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Keselamatan</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Berkeadaan</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Cipta VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Ralat Import</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Ralat fail</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proksi VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Jenis Proksi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Pelayan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Cuba Lagi Tanpa Henti Bila Gagal</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Fail CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Abai Amaran Sijil</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Guna Sambungan Nama Hos TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Keselamatan VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Lalai</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Sifer</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Pengesahihan HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Disimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pilihan Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domain NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proksi VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Pelayan</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kunci Persendirian</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Ejen SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Kad Pintar</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Kunci Pra-Kongsi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Sijil CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Jenis Pengesahihan</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Sijil Pengguna</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Pinta satu Alamat IP Dalaman</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Paksa Pengurungan UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Guna pemampatan IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Benarkan Saranan Sifer Suai</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Pengesahihan TLS VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Lalai</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klien</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Pelayan</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subjek Sepadan</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Jenis Sijil Jauh</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fail Kunci</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Suaikan Arah Kunci</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Arah Kunci</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Get laluan tidak sah</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Disimpan</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Tanya</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tidak Diperlukan</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pilihan Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nama Kumpulan</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Pwd Kumpulan</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Guna Pengesahihan Hidbrid</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fail CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Palamkan dahulu kabel rangkaian</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Penyesuai Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tambah Sambungan Rangkaian</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Pilih Tetapan</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Penyesuai Rangkaian Tanpa Wayar</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Tutup Kawasan Khas</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Lumpuhkan kawasan khas jika anda mahu bersambung dengan rangkaian tanpa wayar.</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Sambung ke rangkaian tersembunyi</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Tidak Diikat</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Alamat MAC Peranti</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Suaikan MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>